# Geodesic module

Bound timelike geodesics are defined in terms of the Keplerian-like parameters:

- $a$ : the dimensionless Kerr spin parameter
- $p$ : the dimensionless semilatus rectum
- $e$ : the orbital eccentricty
- $x$ : cosine of the orbital inclination

## API

```{eval-rst}
.. automodule:: pybhpt.geo
   :no-index:
   :members:
   :undoc-members:
   :show-inheritance:
```
